import React from 'react';
import { LinkProps, NavigateProps } from 'react-router-dom';
import { CheckParamReq, ExtractParams, Pattern, RoutePattern, To, TypedPathMatch, TypedPathPattern } from './types';
import { TypedNavigateFunction } from './useTypedNavigate';
declare module 'react' {
    function forwardRef<T, P = {}>(render: (props: P, ref: React.Ref<T>) => React.ReactElement | null): (props: P & React.RefAttributes<T>) => React.ReactElement | null;
}
export interface TypedLinkProps<RoutePattern extends string> extends Omit<LinkProps, 'to' | 'replace'> {
    to: To<RoutePattern>;
    params: ExtractParams<RoutePattern>;
}
export interface TypedNavigateProps<RoutePattern extends string> extends Omit<NavigateProps, 'to' | 'replace'> {
    to: To<RoutePattern>;
    params: ExtractParams<RoutePattern>;
}
export declare const constructTypedRouter: <T>(routes: T) => {
    Link: <Pattern_1 extends RoutePattern<T> & string>(props: CheckParamReq<TypedLinkProps<Pattern_1>> & React.RefAttributes<HTMLAnchorElement>) => React.ReactElement | null;
    Navigate<Pattern_2 extends RoutePattern<T> & string>(props: CheckParamReq<TypedNavigateProps<Pattern_2>>): JSX.Element;
    useMatch: (pattern: Pattern<RoutePattern<T> & string>) => TypedPathMatch<RoutePattern<T> & string, ExtractParams<RoutePattern<T> & string, string>>;
    useNavigate: () => TypedNavigateFunction<RoutePattern<T> & string>;
    matchPath: (pattern: TypedPathPattern<RoutePattern<T> & string>, pathname: string) => TypedPathMatch<RoutePattern<T> & string, ExtractParams<RoutePattern<T> & string, string>>;
    generatePath<Pattern_3 extends RoutePattern<T> & string>(path: Pattern_3, params: ExtractParams<Pattern_3, string>): string;
};
